import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The ``AWS::RDS::DBClusterParameterGroup`` resource creates a new Amazon RDS DB cluster parameter group.
 *  For information about configuring parameters for Amazon Aurora DB clusters, see [Working with parameter groups](https://docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_WorkingWithParamGroups.html) in the *Amazon Aurora User Guide*.
 *   If you apply a parameter group to a DB cluster, then its DB instances might need to reboot. This can result in an outage while the DB instances are rebooting.
 *  If you apply a change to parameter group associated with a stopped DB cluster, then the updated stack waits until the DB cluster is started.
 */
export declare class DbClusterParameterGroup extends pulumi.CustomResource {
    /**
     * Get an existing DbClusterParameterGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DbClusterParameterGroup;
    /**
     * Returns true if the given object is an instance of DbClusterParameterGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DbClusterParameterGroup;
    /**
     * The name of the DB cluster parameter group.
     *  Constraints:
     *   +  Must not match the name of an existing DB cluster parameter group.
     *
     *   This value is stored as a lowercase string.
     */
    readonly dbClusterParameterGroupName: pulumi.Output<string | undefined>;
    /**
     * The description for the DB cluster parameter group.
     */
    readonly description: pulumi.Output<string>;
    /**
     * The DB cluster parameter group family name. A DB cluster parameter group can be associated with one and only one DB cluster parameter group family, and can be applied only to a DB cluster running a database engine and engine version compatible with that DB cluster parameter group family.
     *   *Aurora MySQL*
     *  Example: ``aurora-mysql5.7``, ``aurora-mysql8.0``
     *   *Aurora PostgreSQL*
     *  Example: ``aurora-postgresql14``
     *   *RDS for MySQL*
     *  Example: ``mysql8.0``
     *   *RDS for PostgreSQL*
     *  Example: ``postgres13``
     *  To list all of the available parameter group families for a DB engine, use the following command:
     *   ``aws rds describe-db-engine-versions --query "DBEngineVersions[].DBParameterGroupFamily" --engine <engine>``
     *  For example, to list all of the available parameter group families for the Aurora PostgreSQL DB engine, use the following command:
     *   ``aws rds describe-db-engine-versions --query "DBEngineVersions[].DBParameterGroupFamily" --engine aurora-postgresql``
     *   The output contains duplicates.
     *   The following are the valid DB engine values:
     *   +   ``aurora-mysql``
     *   +   ``aurora-postgresql``
     *   +   ``mysql``
     *   +   ``postgres``
     */
    readonly family: pulumi.Output<string>;
    /**
     * Provides a list of parameters for the DB cluster parameter group.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::RDS::DBClusterParameterGroup` for more information about the expected schema for this property.
     */
    readonly parameters: pulumi.Output<any>;
    /**
     * Tags to assign to the DB cluster parameter group.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a DbClusterParameterGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DbClusterParameterGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DbClusterParameterGroup resource.
 */
export interface DbClusterParameterGroupArgs {
    /**
     * The name of the DB cluster parameter group.
     *  Constraints:
     *   +  Must not match the name of an existing DB cluster parameter group.
     *
     *   This value is stored as a lowercase string.
     */
    dbClusterParameterGroupName?: pulumi.Input<string>;
    /**
     * The description for the DB cluster parameter group.
     */
    description: pulumi.Input<string>;
    /**
     * The DB cluster parameter group family name. A DB cluster parameter group can be associated with one and only one DB cluster parameter group family, and can be applied only to a DB cluster running a database engine and engine version compatible with that DB cluster parameter group family.
     *   *Aurora MySQL*
     *  Example: ``aurora-mysql5.7``, ``aurora-mysql8.0``
     *   *Aurora PostgreSQL*
     *  Example: ``aurora-postgresql14``
     *   *RDS for MySQL*
     *  Example: ``mysql8.0``
     *   *RDS for PostgreSQL*
     *  Example: ``postgres13``
     *  To list all of the available parameter group families for a DB engine, use the following command:
     *   ``aws rds describe-db-engine-versions --query "DBEngineVersions[].DBParameterGroupFamily" --engine <engine>``
     *  For example, to list all of the available parameter group families for the Aurora PostgreSQL DB engine, use the following command:
     *   ``aws rds describe-db-engine-versions --query "DBEngineVersions[].DBParameterGroupFamily" --engine aurora-postgresql``
     *   The output contains duplicates.
     *   The following are the valid DB engine values:
     *   +   ``aurora-mysql``
     *   +   ``aurora-postgresql``
     *   +   ``mysql``
     *   +   ``postgres``
     */
    family: pulumi.Input<string>;
    /**
     * Provides a list of parameters for the DB cluster parameter group.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::RDS::DBClusterParameterGroup` for more information about the expected schema for this property.
     */
    parameters: any;
    /**
     * Tags to assign to the DB cluster parameter group.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
